==> poseutil-0.2.2-py3-none-any.whl: utils/qt_component.py <==
from PyQt5.QtGui import QFont, QIcon
from PyQt5.QtWidgets import QTableWidgetItem
from PyQt5.QtCore import *
from PyQt5.QtWidgets import QSlider, QPushButton
from PyQt5 import QtWidgets

def listViewSetup(list_widget, row, connect):
    for i in row:
        if ".DS_Store" in i:
            continue
        list_widget.addItem(i)
    list_widget.currentItemChanged.connect(connect)
    
def checkBoxSetup(checkBox, toolTip, toggle, connect):
    checkBox.setToolTip(toolTip)
    if toggle:
        checkBox.toggle()
    checkBox.stateChanged.connect(connect)


def labelSetup(label, move, title, fontSize = 15):
    label.move(move[0], move[1])
    label.setFont(QFont(title, fontSize))
    label.setText(title)
    label.show()

def sliderSetup(slider, label, move, range, step, defaultValue, connectData, val=1):
    slider.move(move[0], move[1])
    slider.setRange(range[0], range[1])
    slider.setSingleStep(step)
    slider.setValue(defaultValue)
    slider.valueChanged.connect(lambda: label.setText(str(round(slider.value() * val, 1))))
    slider.valueChanged.connect(connectData)
    slider.show()

def btnSetup(btn, toolTip, font, move, resize, connect):
    btn.setToolTip(toolTip)
    btn.setFont(font)
    btn.move(move[0], move[1])
    btn.resize(resize[0], resize[1])
    btn.clicked.connect(connect)

def btnSetting(btn, toolTip, font, clickedEvent):
    btn.setToolTip(toolTip)
    btn.setFont(font)
    btn.resize(btn.sizeHint())
    btn.clicked.connect(clickedEvent)

def tableSetup(table, rows, cols, data=None, row_header=None, col_header=None):
    table.setRowCount(rows)
    table.setColumnCount(cols)
    if row_header is not None:
        table.setHorizontalHeaderLabels(row_header)
    if col_header is not None:
        table.setVerticalHeaderLabels(col_header)
    if data is None: 
        return
    for idx, val in enumerate(data):
        if type(val) is list:
            for idx_2, val_2 in enumerate(val):
                item = QTableWidgetItem(str(val_2))
                table.setItem(idx_2, idx, item)
        else:
            item = QTableWidgetItem(val)
            table.setItem(idx, 0, item)
    table.resizeColumnsToContents()
    table.resizeRowsToContents()

def comboBoxSetup(combo_box, item_list, connect):
    for item in item_list:
        combo_box.addItem(item)
    combo_box.activated[str].connect(connect)

def easySliderSetup(sd, connect, range=(0,100), step=1, defalut_value = 0):
    sd.setRange(range[0], range[1])
    sd.setSingleStep(step)
    sd.setValue(defalut_value)
    sd.valueChanged.connect(connect)

class PlaySliderBar(QtWidgets.QMainWindow):
    def __init__(self):
        QtWidgets.QMainWindow.__init__(self)
        self.slider = QSlider(Qt.Horizontal, self)
        self.pb_play = QPushButton('', self)
        self.pb_play.setIcon(QIcon('imgs/pause.png'))
        self.pb_play_is_clicked = False
        self.curFrameNum = 0
        self.timer = QTimer()
        self.timer.setInterval(1)
        self.timer.timeout.connect(self.playOnChangedFrameNum)
        self.setUpUI()
    
    def setUpUI(self):
        self.main_widget = QtWidgets.QWidget(self)
        self.mainLayout = QtWidgets.QGridLayout(self.main_widget)
        easySliderSetup(self.slider, self.onChangedFrameNum)
        self.pb_play.clicked.connect(self.onClickedPlayBtn)

        self.mainLayout.addWidget(self.pb_play, 0, 0, 1, 1)
        self.mainLayout.addWidget(self.slider, 0, 1, 1, 1)
        self.main_widget.setFocus()
        self.setCentralWidget(self.main_widget)
    
    def onClickedPlayBtn(self):
        if self.pb_play_is_clicked:
            self.pb_play.setIcon(QIcon('imgs/play.png'))
            self.timer.stop()
        else:
            self.pb_play.setIcon(QIcon('imgs/pause.png'))
            self.timer.start()
        self.pb_play_is_clicked = not self.pb_play_is_clicked
    
    def onChangedFrameNum(self, value):
        self.curFrameNum = value

    def playOnChangedFrameNum(self):
        self.curFrameNum += 1
        self.onChangedFrameNum(self.curFrameNum)
        self.slider.setValue(self.curFrameNum)

==> poseutil-0.2.3-py3-none-any.whl: utils/qt_component.py <==
from PyQt5.QtGui import QFont, QIcon
from PyQt5.QtWidgets import QTableWidgetItem
from PyQt5.QtCore import *
from PyQt5.QtWidgets import QSlider, QPushButton
from PyQt5 import QtWidgets

def listViewSetup(list_widget, row, connect):
    for i in row:
        if ".DS_Store" in i:
            continue
        list_widget.addItem(i)
    list_widget.currentItemChanged.connect(connect)
    
def checkBoxSetup(checkBox, toolTip, toggle, connect):
    checkBox.setToolTip(toolTip)
    if toggle:
        checkBox.toggle()
    checkBox.stateChanged.connect(connect)


def labelSetup(label, move, title, fontSize = 15):
    label.move(move[0], move[1])
    label.setFont(QFont(title, fontSize))
    label.setText(title)
    label.show()

def sliderSetup(slider, label, move, range, step, defaultValue, connectData, val=1):
    slider.move(move[0], move[1])
    slider.setRange(range[0], range[1])
    slider.setSingleStep(step)
    slider.setValue(defaultValue)
    slider.valueChanged.connect(lambda: label.setText(str(round(slider.value() * val, 1))))
    slider.valueChanged.connect(connectData)
    slider.show()

def btnSetup(btn, toolTip, font, move, resize, connect):
    btn.setToolTip(toolTip)
    btn.setFont(font)
    btn.move(move[0], move[1])
    btn.resize(resize[0], resize[1])
    btn.clicked.connect(connect)

def btnSetting(btn, toolTip, font, clickedEvent):
    btn.setToolTip(toolTip)
    btn.setFont(font)
    btn.resize(btn.sizeHint())
    btn.clicked.connect(clickedEvent)

def tableSetup(table, rows, cols, data=None, row_header=None, col_header=None):
    table.setRowCount(rows)
    table.setColumnCount(cols)
    if row_header is not None:
        table.setHorizontalHeaderLabels(row_header)
    if col_header is not None:
        table.setVerticalHeaderLabels(col_header)
    if data is None: 
        return
    for idx, val in enumerate(data):
        if type(val) is list:
            for idx_2, val_2 in enumerate(val):
                item = QTableWidgetItem(str(val_2))
                table.setItem(idx_2, idx, item)
        else:
            item = QTableWidgetItem(val)
            table.setItem(idx, 0, item)
    table.resizeColumnsToContents()
    table.resizeRowsToContents()

def comboBoxSetup(combo_box, item_list, connect):
    for item in item_list:
        combo_box.addItem(item)
    combo_box.activated[str].connect(connect)

def easySliderSetup(sd, connect, range=(0,100), step=1, defalut_value = 0):
    sd.setRange(range[0], range[1])
    sd.setSingleStep(step)
    sd.setValue(defalut_value)
    sd.valueChanged.connect(connect)

class PlaySliderBar(QtWidgets.QMainWindow):
    def __init__(self):
        QtWidgets.QMainWindow.__init__(self)
        self.slider = QSlider(Qt.Horizontal, self)
        self.pb_play = QPushButton('', self)
        self.pb_play.setIcon(QIcon('imgs/play.png'))
        self.pb_play_is_clicked = True
        self.curFrameNum = 0
        self.timer = QTimer()
        self.timer.setInterval(1)
        self.timer.timeout.connect(self.playOnChangedFrameNum)
        self.setUpUI()
    
    def setUpUI(self):
        self.main_widget = QtWidgets.QWidget(self)
        self.mainLayout = QtWidgets.QGridLayout(self.main_widget)
        easySliderSetup(self.slider, self.onChangedFrameNum)
        self.pb_play.clicked.connect(self.onClickedPlayBtn)

        self.mainLayout.addWidget(self.pb_play, 0, 0, 1, 1)
        self.mainLayout.addWidget(self.slider, 0, 1, 1, 1)
        self.main_widget.setFocus()
        self.setCentralWidget(self.main_widget)
    
    def onClickedPlayBtn(self):
        if self.pb_play_is_clicked:
            self.pb_play.setIcon(QIcon('imgs/play.png'))
            self.timer.stop()
        else:
            self.pb_play.setIcon(QIcon('imgs/pause.png'))
            self.timer.start()
        self.pb_play_is_clicked = not self.pb_play_is_clicked
    
    def onChangedFrameNum(self, value):
        self.curFrameNum = value

    def playOnChangedFrameNum(self):
        self.curFrameNum += 1
        self.onChangedFrameNum(self.curFrameNum)
        self.slider.setValue(self.curFrameNum)
